@@ -1,6 +1,6 @@
 # 
 # namcap rules - __init__
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,9 +17,44 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-__tarball__ = ['depends', 'directoryname', 'fileownership', 'gnomemenu', 'perllocal', 'permissions', 'symlink', 'urlpkg', 'capsnamespkg', 'emptydir', 'scrollkeeper', 'libtool', 'gnomemime', 'licensepkg', 'infodirectory', 'fhsmanpages']
+__tarball__ = """
+  capsnamespkg
+  depends
+  directoryname
+  elffiles
+  emptydir
+  fhsmanpages
+  fhsinfopages
+  fileownership
+  gnomemime
+  hicoloricons
+  infodirectory
+  libtool
+  licensepkg
+  mimefiles
+  perllocal
+  permissions
+  scrollkeeper
+  symlink
+  urlpkg
 
-__pkgbuild__ = ['md5sums', 'tags', 'url', 'invalidstartdir', 'capsnames', 'carch', 'sfurl', 'badbackups', 'license', 'arrays']
+""".split()
+
+__pkgbuild__ = """
+  arrays
+  badbackups
+  capsnames
+  carch
+  invalidstartdir
+  license
+  md5sums
+  pkgname
+  rpath
+  sfurl
+  tags
+  url
+
+""".split()
 
 __all__ = __tarball__ + __pkgbuild__
 
