@@ -1,6 +1,6 @@
 # 
 # namcap rules - capsnamespkg
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class package:
 	def analyze(self, pkginfo, tar):
 		ret = [[],[],[]]
 		if re.search('[A-Z]', pkginfo.name) != None:
-			ret[0].append('No upper case letters in package names')
+			ret[0].append(("package-name-in-uppercase", ()))
 		return ret
 	def type(self):
 		return "tarball"
