@@ -1,6 +1,6 @@
 # 
 # namcap rules - tags
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ class package:
 	def short_name(self):
 		return "tags"
 	def long_name(self):
-		return "Looks for Maintainer and CVS Id tags"
+		return "Looks for Maintainer and Contributor comments"
 	def prereq(self):
 		return ""
 	def analyze(self, pkginfo, tar):
@@ -36,21 +36,13 @@ class package:
 				contributortag = 1
 			if re.match("#\s*Maintainer\s*:",i) != None:
 				maintainertag = 1
-			if re.match("#\s*\$Id.*\$",i) != None:
-				idtag = 1
 
 		if contributortag != 1:
-			ret[1].append('Missing Contributor tag')
+			ret[2].append(("missing-contributor", ()))
 
 		if maintainertag != 1:
-			ret[1].append('Missing Maintainer tag')
-		else:
-			ret[2].append('Maintainer tags for TUs and devs only')
+			ret[1].append(("missing-maintainer", ()))
 
-		if idtag != 1:
-			ret[1].append('Missing CVS Id tag')
-		else:
-			ret[2].append('CVS Id tags for TUs and devs only')
 		return ret
 	def type(self):
 		return "pkgbuild"
