@@ -1,6 +1,6 @@
 # 
 # namcap rules - urlpkg
-# Copyright (C) 2003-2007 Jason Chu <jason@archlinux.org>
+# Copyright (C) 2003-2009 Jason Chu <jason@archlinux.org>
 # 
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class package:
 	def analyze(self, pkginfo, tar):
 		ret = [[],[],[]]
 		if not hasattr(pkginfo, 'url'):
-			ret[0].append('Missing url')
+			ret[0].append(("missing-url", ()))
 		return ret
 	def type(self):
 		return "tarball"
